@@ -6,7 +6,7 @@ use DBI ();
 
 use strict;
 
-#$Id: AuthenDBI.pm,v 1.2 1997/05/11 20:25:40 mergl Exp $
+#$Id: AuthenDBI.pm,v 1.4 1997/05/16 05:10:20 mergl Exp $
 
 require_version DBI 0.81;
 
@@ -31,10 +31,12 @@ sub handler {
 
     print STDERR "\nApache::AuthenDBI::handler\n" if $DEBUG;
 
+    return OK unless $r->is_initial_req; #only the first internal request
+
     # here the dialog pops up and asks you for userid and password
     my($res, $passwd_sent) = $r->get_basic_auth_pw;
     print STDERR "get_basic_auth = $res, password sent = $passwd_sent\n" if $DEBUG;
-    return $res if $res; # return on first internal request (res = 401)
+    return $res if $res; # e.g. HTTP_UNAUTHORIZED
 
     my($key, $val);
     my $attr = { };
